from datetime import datetime, UTC
import os
from ocpp.routing import on
from ocpp.v201 import ChargePoint as cp
from ocpp.v201 import call_result
from ocpp.v201.enums import Action, RegistrationStatusType, AuthorizationStatusType

class ChargePoint(cp):
    @on(Action.BootNotification)
    async def on_boot_notification(self, charging_station, reason, **kwargs):
        return call_result.BootNotificationPayload(
            current_time=datetime.now(UTC).isoformat(),
            interval=int(os.getenv("CS_HEARTBEAT_INTERVAL", "1800")),
            status=RegistrationStatusType.accepted
        )
    
    @on(Action.Heartbeat)
    async def on_heartbeat_request(self):
        return call_result.HeartbeatPayload(
            current_time=datetime.now(UTC).isoformat()
        )
    
    @on(Action.StatusNotification)
    async def on_status_notification(self, evse_id, connector_id, connector_status, **kwargs):
        return call_result.StatusNotificationPayload()
    
    @on(Action.Authorize)
    async def on_authorize(self):
        return call_result.AuthorizePayload(id_token_info={'status': AuthorizationStatusType.accepted, 'groupIdToken': ""})
    
    @on(Action.TransactionEvent)
    async def on_transaction_event(self):
        return call_result.TransactionEventPayload()
